@@ -1,14 +1,12 @@
 package UV::Signal;
 
-our $VERSION = '1.908_002';
+our $VERSION = '1.903';
 
 use strict;
 use warnings;
 use Carp ();
 use parent 'UV::Handle';
 
-our @EXPORT_OK = (@UV::Signal::EXPORT_XS,);
-
 sub _new_args {
     my ($class, $args) = @_;
     my $signum = delete $args->{signal} // delete $args->{single_arg};
@@ -40,7 +38,7 @@ UV::Signal - Signal handles in libuv
   use warnings;
 
   use UV;
-  use UV::Signal qw(SIGINT);
+  use POSIX qw(SIGINT);
 
   # A new handle will be initialised against the default loop
   my $signal = UV::Signal->new(signal => SIGINT);
@@ -123,8 +121,6 @@ starts the handle.
 Note that the signal number is given to the constructor, not the C<start>
 method.
 
-Returns the C<$signal> instance itself.
-
 =head2 stop
 
     $signal->stop();
