@@ -1,6 +1,6 @@
 package UV::UDP;
 
-our $VERSION = '1.908_002';
+our $VERSION = '1.903';
 
 use strict;
 use warnings;
@@ -120,8 +120,6 @@ method starts the receiving side of the UDP socket handle. The C<recv> event
 callback will be invoked whenever there is new data to be given to the
 application.
 
-Returns the C<$udp> instance itself.
-
 =head2 recv_stop
 
     $udp->recv_stop;
